@@ -33,11 +33,15 @@ void flushText(std::string &text, librevenge::RVNGDrawingInterface *const painte
   }
 }
 
-void writeTextSpan(const std::string &text, const std::size_t charStart, const std::size_t charEnd, const bool capsFlag, librevenge::RVNGDrawingInterface *const painter)
+void writeTextSpan(const std::string &text, const std::size_t charStart, std::size_t charEnd, const bool capsFlag, librevenge::RVNGDrawingInterface *const painter)
 {
+  ++charEnd;
+  if (charEnd > text.size())
+    charEnd = text.size();
+
   std::string currentText;
   bool wasSpace = false;
-  for (std::size_t i = charStart; i <= charEnd; ++i)
+  for (std::size_t i = charStart; i < charEnd; ++i)
   {
     const char c = text[i];
 
@@ -700,8 +704,8 @@ void PMDCollector::fillOutputShapesByPage_TwoSided(PageShapesList_t &pageShapes)
 {
   pageShapes.assign(m_pages.size() * 2 - 1, PageShapes_t()); // the first "page" only has right side
 
-  double centerToEdge_x = m_pageWidth.get().toInches() / 2;
-  double centerToEdge_y = m_pageHeight.get().toInches() / 2;
+  double centerToEdge_x = m_pageWidth.get_value_or(0).toInches() / 2;
+  double centerToEdge_y = m_pageHeight.get_value_or(0).toInches() / 2;
   InchPoint translateForLeftPage(centerToEdge_x * 2, centerToEdge_y);
   InchPoint translateForRightPage(0, centerToEdge_y);
 
@@ -729,7 +733,7 @@ void PMDCollector::fillOutputShapesByPage_TwoSided(PageShapesList_t &pageShapes)
     }
   }
 
-  if (pageShapes.back().empty()) // the last "page" only has left side
+  if ((pageShapes.size() > 1) && pageShapes.back().empty()) // the last "page" only has left side
     pageShapes.pop_back();
 }
 
